#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# about_dialog.pyw
# 
# something about OpenSecurity
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2014 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import sys

from PyQt4 import QtCore
from PyQt4 import QtGui

from ui_AboutDialog import Ui_AboutDialog

try:
    # mhm, bit of a hack to get the ../__init__.py loaded
    import os.path
    f = os.path.normpath(os.path.join(os.path.split(__file__)[0], '..', '__init__.py'))
    import imp
    opensecurity = imp.load_source('opensecurity', f)
    __version__ = opensecurity.__version__

except:
    # failed to get the ../__init__.py loaded :(
    __version__ = 'N/A'


# ------------------------------------------------------------
# code


ABOUT_TEXT = """
<html>

<head>

<style type="text/css">
    .header { margin-bottom: 50px; }
    .logo { vertical-align: middle; margin-bottom: 24px; }
    .logo { vertical-align: middle; margin-bottom: 24px; }
    .footer { margin-top: 100px; }
</style>

</head>

<body bgcolor="#FFFFFF">

<div align="center">

<h1 class="header">
    <a href="http://www.opensecurity.at"><img src=":/opensecurity/gfx/opensecurity_logo.jpg"/></a><br/><br/>
    OpenSecurity V%s
</h1>

<div class="about_text" align="left">
    OpenSecurity is an Austrian national project funded by the FFG KIRAS program.<br/>
    <br/>
    The goal of the project is to help to prevent the loss and (un)intentional misuse of sensitive, <br/>
    citizen-related data held by public bodies through the application of "security by isolation" approaches. <br/>
    <br/>
    The OpenSecurity consortium consists of small businesses (X-Net Services GmbH, IKARUS Security Software GmbH), <br/>
    research institutions (AIT Austrian Institute of Technology GmbH, Linzer Institut f&uuml;r qualitative Analysen), <br/>
    and public stakeholders (Bundesministerium f&uuml;r Landesverteidigung und Sport, IKT Linz Infrastruktur GmbH). <br/>
</div>

<div class="logo">
    <a href="http://www.ait.ac.at"><img src=":/opensecurity/gfx/ait_logo_no_claim.png"/></a>
    <a href="http://www.x-net.at"><img src=":/opensecurity/gfx/x-net_logo.jpg"/></a>
    <a href="http://www.ikarussecurity.com"><img src=":/opensecurity/gfx/ikarus_logo.jpg"/></a>
</div>

<div class="logo">
    <a href="http://www.liqua.net"><img src=":/opensecurity/gfx/liqua_logo.jpg"/></a>
    <a href="http://www.linz.at"><img src=":/opensecurity/gfx/linz_logo.jpg"/></a>
    <a href="http://www.bmvit.gv.at"><img src=":/opensecurity/gfx/bmvit_logo.jpg"/></a>
</div>

<div class="logo">
    <a href="http://www.ffg.at"><img src=":/opensecurity/gfx/ffg_logo.jpg"/></a>
    <a href="http://www.kiras.at"><img src=":/opensecurity/gfx/kiras_logo.jpg"/></a>
</div>

<div class="footer" align="left">
    Copyright (C) 2013, 2014 AIT Austrian Institute of Technology<br/>
    AIT Austrian Institute of Technology GmbH<br/>
    Donau-City-Strasse 1 | 1220 Vienna | Austria<br/>
    <a href="http://www.ait.ac.at">http://www.ait.ac.at</a>
</div>

</div>
</body>
</html>
""";


# ------------------------------------------------------------
# code


class AboutDialog(QtGui.QDialog):

    """A dialog which shows some information about the OpenSecurity project"""

    def __init__(self):

        QtGui.QDialog.__init__(self)

        # setup the user interface
        self.ui = Ui_AboutDialog()
        self.ui.setupUi(self)
   
        # fix the scroll area content
        self.ui.lblAbout = QtGui.QLabel(ABOUT_TEXT)
        self.ui.lblAbout.setContentsMargins(16, 16, 16, 16)
        self.ui.lblAbout.setStyleSheet(self.ui.scrAboutContent.styleSheet())
        self.ui.scrAbout.setWidget(self.ui.lblAbout)

        # connectors
        self.ui.btnOk.clicked.connect(self.accept)
        self.ui.lblAbout.setText(ABOUT_TEXT % __version__)


if __name__ == "__main__":
    a = QtGui.QApplication(sys.argv)
    d = AboutDialog()
    d.show()
    sys.exit(a.exec_())     

